==> gst-plugins-dsp0.10_0.62-1.tar.gz: gst-plugins-dsp0.10-0.62/dsppcm/gstdsppcmsink.h <==
/*
 * This file is part of libgst0.10-dsp
 *
 * Copyright (C) 2006 Nokia Corporation. All rights reserved.
 *
 * Contact: Stefan Kost <stefan.kost@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#ifndef __GST_DSPPCMSINK_H__
#define __GST_DSPPCMSINK_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <gst/gst.h>
#include <gst/base/gstbasesink.h>

#include <dspaudio.h>
#include <dsp/interface_common.h>
#include <dsp/audio_dsptask.h>

G_BEGIN_DECLS

#define GST_TYPE_DSPPCMSINK          (gst_dsppcmsink_get_type())
#define GST_DSPPCMSINK(obj)          (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_DSPPCMSINK,GstDSPPcmSink))
#define GST_DSPPCMSINK_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_DSPPCMSINK,GstDSPPcmSinkClass))
#define GST_IS_DSPPCMSINK(obj)       (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_DSPPCMSINK))
#define GST_IS_DSPPCMSINK_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_DSPPCMSINK))

typedef enum
{
  DSPPCMSINK_PROP_AEC_MODE = DSPAUDIO_PROP_LAST,
  DSPPCMSINK_PROP_LAST
} DSPPCMSinkProperties;

typedef enum {
  GST_DSPPCMSINK_AEC_OFF,
  GST_DSPPCMSINK_AEC_ON,
} GstPCMSinkAECModes;

enum
{
  DSPPCM_SIGNAL_STREAMID,
  DSPPCM_SIGNAL_LAST
};

typedef struct _GstDSPPcmSink GstDSPPcmSink;
typedef struct _GstDSPPcmSinkClass GstDSPPcmSinkClass;

/* PCM data write structure */
typedef struct pcm_data_write
{
  unsigned short int dsp_cmd;
  unsigned short int data_size;
} PCM_DATA_WRITE;



struct _GstDSPPcmSink {
  GstBaseSink   sink;
  GstDSPAudio   *audio;

  // audio stream info
  gint           width;
  gint           depth;
  gint           channels_fmt;
  gint           rate_fmt;
  gint           endianness;
  gint           law;
  guint          bps;
  guint          format;
  gboolean       sign;

  // "Raw values"
  gint           rate;
  gint           channels;

  guint          outIndex;
  guint          buf_limit;

  GstPCMSinkAECModes aec_mode;
  PCM_DATA_WRITE outbuf;
};

struct _GstDSPPcmSinkClass {
  GstBaseSinkClass parent_class;

  void (*stream_id) (GstDSPPcmSink *sink, gint id);
};


GType gst_dsppcmsink_get_type(void);

G_END_DECLS

#endif /* __GST_DSPPCMSINK_H__ */

==> gst-plugins-dsp0.10_1.10.17.tar.gz: gst-plugins-dsp0.10-1.10.17/dsppcm/gstdsppcmsink.h <==
/*
 * This file is part of libgst0.10-dsp
 *
 * Copyright (C) 2006 Nokia Corporation. All rights reserved.
 *
 * Contact: Stefan Kost <stefan.kost@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#ifndef __GST_DSPPCMSINK_H__
#define __GST_DSPPCMSINK_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <gst/gst.h>
#include <gst/base/gstbasesink.h>

#include <dspaudio.h>
#include <dsp/interface_common.h>
#include <dsp/audio_dsptask.h>

G_BEGIN_DECLS

#define GST_TYPE_DSPPCMSINK            (gst_dsppcmsink_get_type())
#define GST_DSPPCMSINK(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_DSPPCMSINK,GstDSPPcmSink))
#define GST_DSPPCMSINK_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_DSPPCMSINK,GstDSPPcmSinkClass))
#define GST_IS_DSPPCMSINK(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_DSPPCMSINK))
#define GST_IS_DSPPCMSINK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_DSPPCMSINK))

typedef enum
{
  DSPPCMSINK_PROP_AEC_MODE = DSPAUDIO_PROP_LAST,
  DSPPCMSINK_PROP_LAST
} DSPPCMSinkProperties;

typedef enum {
  GST_DSPPCMSINK_AEC_OFF,
  GST_DSPPCMSINK_AEC_ON,
} GstPCMSinkAECModes;

enum
{
  DSPPCM_SIGNAL_STREAMID,
  DSPPCM_SIGNAL_LAST
};

typedef struct _GstDSPPcmSink GstDSPPcmSink;
typedef struct _GstDSPPcmSinkClass GstDSPPcmSinkClass;

/* PCM data write structure */
typedef struct pcm_data_write
{
  unsigned short int dsp_cmd;
  unsigned short int data_size;
} PCM_DATA_WRITE;



struct _GstDSPPcmSink {
  GstBaseSink   sink;
  GstDSPAudio   *audio;
  GstClock      *clock;

  // audio stream info
  gint           width;
  gint           depth;
  gint           channels_fmt;
  gint           rate_fmt;
  gint           endianness;
  gint           law;
  guint          bps;
  guint          format;
  gboolean       sign;

  // "Raw values"
  gint           rate;
  gint           channels;

  guint          outIndex;
  guint          buf_limit;

  GstPCMSinkAECModes aec_mode;
  PCM_DATA_WRITE outbuf;
};

struct _GstDSPPcmSinkClass {
  GstBaseSinkClass parent_class;

  void (*stream_id) (GstDSPPcmSink *sink, gint id);
};


GType gst_dsppcmsink_get_type(void);

G_END_DECLS

#endif /* __GST_DSPPCMSINK_H__ */
